==> crm-commom-1.2.2.45.release.jar: com/biz/crm/util/dms/PromotionPolicyUtil.java <==
package com.biz.crm.util.dms;


import com.biz.crm.eunm.CrmEnableStatusEnum;
import com.biz.crm.eunm.dms.PromotionPolicyEunm;
import com.biz.crm.util.CrmDateUtils;
import org.apache.commons.lang3.StringUtils;

import java.time.LocalDateTime;
import java.time.ZoneOffset;

public class PromotionPolicyUtil {

    /**
     * 计算政策状态
     * @param enableStatus
     * @param beginTime
     * @param endTime
     * @return
     */
    public static final String promotionPolicyStatus(String enableStatus
            , String beginTime, String endTime){

        if(CrmEnableStatusEnum.DISABLE.getCode().equals(enableStatus)){
            return enableStatus;
        }
        return timeActive(beginTime, endTime);
//        Map<String, String> map = DictUtil.getDictValueMapsByCodes(PromotionPolicyEunm.dict_type_as_promotion_policy_status);
//        if(null == map){
//            return;
//        }
//        this.promotionPolicyStatusName = map.get(this.promotionPolicyStatus);
    }

    /**
     * 计算该政策是否在有效期内
     * 3个业务状态， 待执行：null，执行中：true，已结束：false
     * waiting，执行中：running，已结束：finished
     *  @author: luoqi
     *  @Date: 2020-10-19 15:40
     *  @version: V1.0
     *  @Description:
     */
    public static final String timeActive(String beginTime, String endTime){
        if(StringUtils.isBlank(beginTime) || StringUtils.isBlank(endTime)){
            return PromotionPolicyEunm.PromotionPolicyStatusEunm.WAITING.getCode();
        }
        long tempBegin = LocalDateTime.parse(beginTime, CrmDateUtils.yyyyMMddHHmmss).toEpochSecond(ZoneOffset.of("+8"));
        long tempEnd = LocalDateTime.parse(endTime, CrmDateUtils.yyyyMMddHHmmss).toEpochSecond(ZoneOffset.of("+8"));
        long now = System.currentTimeMillis() / 1000;
        if(tempBegin > now){
            return PromotionPolicyEunm.PromotionPolicyStatusEunm.WAITING.getCode();
        }
        if( now > tempBegin && now < tempEnd){
            return PromotionPolicyEunm.PromotionPolicyStatusEunm.RUNNING.getCode();
        }else{
            return PromotionPolicyEunm.PromotionPolicyStatusEunm.FINISHED.getCode();
        }
    }
}

==> crm-commom-1.3.0.6.55.release.jar: com/biz/crm/util/dms/PromotionPolicyUtil.java <==
package com.biz.crm.util.dms;


import com.biz.crm.eunm.CrmEnableStatusEnum;
import com.biz.crm.eunm.dms.PromotionPolicyEunm;
import com.biz.crm.util.CrmDateUtils;
import org.apache.commons.lang3.StringUtils;

import java.time.LocalDateTime;
import java.time.ZoneOffset;

public class PromotionPolicyUtil {

    /**
     * 计算政策状态
     * @param enableStatus
     * @param beginTime
     * @param endTime
     * @return
     */
    public static final String promotionPolicyStatus(String enableStatus
            , String beginTime, String endTime){

        if(CrmEnableStatusEnum.DISABLE.getCode().equals(enableStatus)){
            return enableStatus;
        }
        return timeActive(beginTime, endTime);
//        Map<String, String> map = DictUtil.getDictValueMapsByCodes(PromotionPolicyEunm.dict_type_as_promotion_policy_status);
//        if(null == map){
//            return;
//        }
//        this.promotionPolicyStatusName = map.get(this.promotionPolicyStatus);
    }

    /**
     * 计算政策状态(去掉enable)
     * @param beginTime
     * @param endTime
     * @return
     */
    public static final String promotionPolicyStatusNoEnable(String beginTime, String endTime){
        return timeActive(beginTime, endTime);
//        Map<String, String> map = DictUtil.getDictValueMapsByCodes(PromotionPolicyEunm.dict_type_as_promotion_policy_status);
//        if(null == map){
//            return;
//        }
//        this.promotionPolicyStatusName = map.get(this.promotionPolicyStatus);
    }

    /**
     * 计算该政策是否在有效期内
     * 3个业务状态， 待执行：null，执行中：true，已结束：false
     * waiting，执行中：running，已结束：finished
     *  @author: luoqi
     *  @Date: 2020-10-19 15:40
     *  @version: V1.0
     *  @Description:
     */
    public static final String timeActive(String beginTime, String endTime){
        if(StringUtils.isBlank(beginTime) || StringUtils.isBlank(endTime)){
            return PromotionPolicyEunm.PromotionPolicyStatusEunm.WAITING.getCode();
        }
        long tempBegin = LocalDateTime.parse(beginTime, CrmDateUtils.yyyyMMddHHmmss).toEpochSecond(ZoneOffset.of("+8"));
        long tempEnd = LocalDateTime.parse(endTime, CrmDateUtils.yyyyMMddHHmmss).toEpochSecond(ZoneOffset.of("+8"));
        long now = System.currentTimeMillis() / 1000;
        if(tempBegin > now){
            return PromotionPolicyEunm.PromotionPolicyStatusEunm.WAITING.getCode();
        }
        if( now > tempBegin && now < tempEnd){
            return PromotionPolicyEunm.PromotionPolicyStatusEunm.RUNNING.getCode();
        }else{
            return PromotionPolicyEunm.PromotionPolicyStatusEunm.FINISHED.getCode();
        }
    }
}
